@@ -4,17 +4,17 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-
 #pragma once
 
-#include <QMainWindow>
 #include "ui_mainwindow.h"
+#include <QMainWindow>
 
 #include "core/types.h"
 #include "tasks/task.h"
 
-namespace KGAPI2 {
-  class Job;
+namespace KGAPI2
+{
+class Job;
 }
 
 class MainWindow : public QMainWindow
@@ -55,4 +55,3 @@ private:
     void enableCreateTaskList(bool enabled);
     void enableCreateTask(bool enabled);
 };
-
